PCB Environment: NavTri Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
NavTri Class Reference

Data associated with a triangle in the Delaunay triangulation of the board. More...

`#include <NavTriangulation.hpp>`

## Public Member Functions
const Triangle_2 & | getTriangle () const
const Color & | getColor () const
void | setVertices (const Point_2 *)
void | setColor (Color c)

## Detailed Description

Data associated with a triangle in the Delaunay triangulation of the board.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavTriangulation.hpp